summaryrefslogtreecommitdiff
path: root/src/char/int_storage.c
diff options
context:
space:
mode:
authorAndrei Karas <akaras@inbox.ru>2014-11-07 17:38:31 +0300
committerAndrei Karas <akaras@inbox.ru>2014-11-15 11:47:29 +0300
commit8338483dd4c41bc9831bebc9d6dc1808247fc497 (patch)
tree62af0b36fdd3552eda22e3197f1d3e0e7fb30fc1 /src/char/int_storage.c
parent9658066ce2f411375b9876d0c02737752b816e58 (diff)
downloadhercules-8338483dd4c41bc9831bebc9d6dc1808247fc497.tar.gz
hercules-8338483dd4c41bc9831bebc9d6dc1808247fc497.tar.bz2
hercules-8338483dd4c41bc9831bebc9d6dc1808247fc497.tar.xz
hercules-8338483dd4c41bc9831bebc9d6dc1808247fc497.zip
Add most functions from char.c to interfaces.
Introduced interfaces: chr, mapif, loginif.
Diffstat (limited to 'src/char/int_storage.c')
-rw-r--r--src/char/int_storage.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/char/int_storage.c b/src/char/int_storage.c
index 07ce8436f..e3b09dea0 100644
--- a/src/char/int_storage.c
+++ b/src/char/int_storage.c
@@ -25,7 +25,7 @@
/// Save storage data to sql
int inter_storage_tosql(int account_id, struct storage_data* p)
{
- char_memitemdata_to_sql(p->items, MAX_STORAGE, account_id, TABLE_STORAGE);
+ chr->memitemdata_to_sql(p->items, MAX_STORAGE, account_id, TABLE_STORAGE);
return 0;
}
@@ -81,7 +81,7 @@ int inter_storage_fromsql(int account_id, struct storage_data* p)
/// Save guild_storage data to sql
int inter_storage_guild_storage_tosql(int guild_id, struct guild_storage* p)
{
- char_memitemdata_to_sql(p->items, MAX_GUILD_STORAGE, guild_id, TABLE_GUILD_STORAGE);
+ chr->memitemdata_to_sql(p->items, MAX_GUILD_STORAGE, guild_id, TABLE_GUILD_STORAGE);
ShowInfo ("guild storage save to DB - guild: %d\n", guild_id);
return 0;
}
@@ -379,9 +379,9 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
//Now let's update the guild storage with those deleted items
/// TODO/FIXME:
/// This approach is basically the same as the one from char_memitemdata_to_sql, but
/// the latter compares current database values and this is not needed in this case
/// maybe sometime separate char_memitemdata_to_sql into different methods in order to use
/// call that function here as well [Panikon]
StrBuf->Clear(&buf);
StrBuf->Printf(&buf,"INSERT INTO `%s` (`guild_id`,`nameid`,`amount`,`equip`,`identify`,`refine`,"
@@ -419,7 +419,7 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
mapif_load_guild_storage(fd,aid,guild_id,0);
// If character is logged in char, disconnect
- char_disconnect_player(aid);
+ chr->disconnect_player(aid);
#endif
return 0;
}
@@ -379,9 +379,9 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
//Now let's update the guild storage with those deleted items
/// TODO/FIXME:
- /// This approach is basically the same as the one from char_memitemdata_to_sql, but
+ /// This approach is basically the same as the one from chr->memitemdata_to_sql, but
/// the latter compares current database values and this is not needed in this case
@@ -379,9 +379,9 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
/// the latter compares current database values and this is not needed in this case
- /// maybe sometime separate char_memitemdata_to_sql into different methods in order to use
+ /// maybe sometime separate chr->memitemdata_to_sql into different methods in order to use
/// call that function here as well [Panikon]
StrBuf->Clear(&buf);